"""Invokes the console scripts for CLI."""

if __name__ == "__main__":
    from ARgorithmToolkit.cli import app
    app()
